@@ -184,6 +184,22 @@ namespace Oxygen
         return false;
     }
 
+    //________________________________________________________
+    std::string Gtk::gtk_widget_path( GtkWidget* widget )
+    {
+
+        if(GTK_IS_WIDGET(widget))
+        {
+            gchar* widgetPath;
+            gtk_widget_path( widget, 0L, &widgetPath, 0L);
+            const std::string  out( widgetPath );
+            g_free( widgetPath );
+            return out;
+        }
+        return std::string("not-widget");
+
+    }
+
     //________________________________________________________
     GtkWidget* Gtk::gtk_widget_find_parent( GtkWidget* widget, GType type )
     {
@@ -328,51 +344,33 @@ namespace Oxygen
     //________________________________________________________
     bool Gtk::gtk_combobox_is_tree_view( GtkWidget* widget )
     {
-        // check types
+        // check types and path
         if( !widget && GTK_IS_TREE_VIEW( widget ) && GTK_IS_SCROLLED_WINDOW( gtk_widget_get_parent( widget ) ) ) return false;
-
-        // retrieve widget path, compare and free
-        gchar* widgetPath;
-        gtk_widget_path( widget, 0L, &widgetPath, 0L);
-        bool out( std::string( widgetPath ) == "gtk-combobox-popup-window.GtkScrolledWindow.GtkTreeView" );
-        g_free( widgetPath );
-        return out;
+        return Gtk::gtk_widget_path( widget ) == "gtk-combobox-popup-window.GtkScrolledWindow.GtkTreeView";
     }
 
     //________________________________________________________
     bool Gtk::gtk_combobox_is_scrolled_window( GtkWidget* widget )
     {
+        // check types and path
         if( !GTK_IS_SCROLLED_WINDOW(widget) ) return false;
-
-        gchar* widgetPath;
-        gtk_widget_path( widget, 0L, &widgetPath, 0L);
-        bool out( std::string( widgetPath ) == "gtk-combobox-popup-window.GtkScrolledWindow" );
-        g_free( widgetPath );
-        return out;
+        return Gtk::gtk_widget_path( widget ) == "gtk-combobox-popup-window.GtkScrolledWindow";
     }
 
     //________________________________________________________
     bool Gtk::gtk_combobox_is_viewport( GtkWidget* widget )
     {
         if( !GTK_IS_VIEWPORT(widget) ) return false;
-        gchar* widgetPath;
-        gtk_widget_path( widget, 0L, &widgetPath, 0L);
         static const std::string match( "gtk-combo-popup-window" );
-        bool out = ( std::string( widgetPath ).substr( 0, match.size() ) == match );
-        g_free( widgetPath );
-        return out;
+        return Gtk::gtk_widget_path( widget ).substr( 0, match.size() ) == match;
     }
 
     //________________________________________________________
     bool Gtk::gtk_combobox_is_frame( GtkWidget* widget )
     {
         if( !GTK_IS_FRAME(widget) ) return false;
-        gchar* widgetPath;
-        gtk_widget_path( widget, 0L, &widgetPath, 0L);
         static const std::string match( "gtk-combo-popup-window" );
-        bool out = ( std::string( widgetPath ).substr( 0, match.size() ) == match );
-        g_free( widgetPath );
-        return out;
+        return Gtk::gtk_widget_path( widget ).substr( 0, match.size() ) == match;
     }
 
     //________________________________________________________
@@ -649,7 +647,7 @@ namespace Oxygen
     }
 
     //________________________________________________________
-    bool Gtk::gdk_map_to_toplevel( GdkWindow* window, GtkWidget* widget, gint* x, gint* y, gint* w, gint* h, bool frame )
+    bool Gtk::gdk_window_map_to_toplevel( GdkWindow* window, gint* x, gint* y, gint* w, gint* h, bool frame )
     {
 
         // always initialize arguments (to invalid values)
@@ -658,38 +656,48 @@ namespace Oxygen
         if( w ) *w = -1;
         if( h ) *h = -1;
 
-        if( !( window && GDK_IS_WINDOW( window ) ) )
+        if( !( window && GDK_IS_WINDOW( window ) ) ) return false;
+
+        // get window size and height
+        if( frame ) gdk_toplevel_get_frame_size( window, w, h );
+        else gdk_toplevel_get_size( window, w, h );
+        Gtk::gdk_window_get_toplevel_origin( window, x, y );
+        return ((!w) || *w > 0) && ((!h) || *h>0);
+
+    }
+
+    //________________________________________________________
+    bool Gtk::gtk_widget_map_to_toplevel( GtkWidget* widget, gint* x, gint* y, gint* w, gint* h, bool frame )
+    {
+
+        // always initialize arguments (to invalid values)
+        if( x ) *x=0;
+        if( y ) *y=0;
+        if( w ) *w = -1;
+        if( h ) *h = -1;
+
+        if( !widget ) return false;
+
+        // this is an alternative way to get widget position with respect to top level window
+        // and top level window size. This is used in case the GdkWindow passed as argument is
+        // actually a 'non window' drawable
+        GdkWindow* window( gtk_widget_get_parent_window( widget ) );
+        if( !( window && GDK_IS_WINDOW( window ) ) ) return false;
+
+        if( frame ) gdk_toplevel_get_frame_size( window, w, h );
+        else gdk_toplevel_get_size( window, w, h );
+        int xlocal, ylocal;
+        const bool success( gtk_widget_translate_coordinates( widget, gtk_widget_get_toplevel( widget ), 0, 0, &xlocal, &ylocal ) );
+        if( success )
         {
-            if( !widget ) return false;
 
-            // this is an alternative way to get widget position with respect to top level window
-            // and top level window size. This is used in case the GdkWindow passed as argument is
-            // actually a 'non window' drawable
-            window = gtk_widget_get_parent_window( widget );
-            if( frame ) gdk_toplevel_get_frame_size( window, w, h );
-            else gdk_toplevel_get_size( window, w, h );
-            int xlocal, ylocal;
-            const bool success( gtk_widget_translate_coordinates( widget, gtk_widget_get_toplevel( widget ), 0, 0, &xlocal, &ylocal ) );
-            if( success )
-            {
-
-                if( x ) *x=xlocal;
-                if( y ) *y=ylocal;
-
-            }
-
-            return success && ((!w) || *w > 0) && ((!h) || *h>0);
-
-        } else {
-
-            // get window size and height
-            if( frame ) gdk_toplevel_get_frame_size( window, w, h );
-            else gdk_toplevel_get_size( window, w, h );
-            Gtk::gdk_window_get_toplevel_origin( window, x, y );
-            return ((!w) || *w > 0) && ((!h) || *h>0);
+            if( x ) *x=xlocal;
+            if( y ) *y=ylocal;
 
         }
 
+        return success && ((!w) || *w > 0) && ((!h) || *h>0);
+
     }
 
     //________________________________________________________
@@ -845,7 +853,7 @@ namespace Oxygen
         GList* children( gtk_container_get_children( GTK_CONTAINER( gtk_dialog_get_action_area( dialog ) ) ) );
 
         #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::Gtk::gtk_dialog_find_button - butons: ";
+        std::cerr << "Oxygen::Gtk::gtk_dialog_find_button - buttons: ";
         #endif
 
         for( GList *child = g_list_first( children ); child; child = g_list_next( child ) )
