@@ -37,16 +37,56 @@ namespace Oxygen
 
     //__________________________________________________________________
     StyleHelper::StyleHelper( void )
+    {}
+
+    //__________________________________________________________________
+    void StyleHelper::initializeRefSurface( void )
     {
+
+        // make sure that surface is not already initialized
+        if( _refSurface.isValid() ) return;
+
         /*
-        create dummy widget, get its window,
-        creates surface for it, and assign to ref surface
+        create dummy widget, check its associated screen;
+        if found create surface for it and save as reference surface
         */
         GtkWidget* widget( gtk_window_new(GTK_WINDOW_TOPLEVEL) );
-        gtk_widget_realize( widget );
-        Cairo::Context context( gtk_widget_get_window( widget ) );
-        _refSurface = Cairo::Surface( cairo_surface_create_similar( cairo_get_target( context ), CAIRO_CONTENT_ALPHA, 1, 1 ) );
-        gtk_widget_destroy( widget );
+        if( gtk_widget_get_screen( widget ) )
+        {
+
+            #if OXYGEN_DEBUG
+            std::cerr
+                << "Oxygen::StyleHelper::initializeRefSurface - "
+                << " widget: " << widget
+                << " screen: " << gtk_widget_get_screen( widget )
+                << std::endl;
+            #endif
+
+            gtk_widget_realize( widget );
+            Cairo::Context context( gtk_widget_get_window( widget ) );
+            _refSurface = Cairo::Surface( cairo_surface_create_similar( cairo_get_target( context ), CAIRO_CONTENT_ALPHA, 1, 1 ) );
+            gtk_widget_destroy( widget );
+
+        } else {
+
+            /*
+            no screen found.
+            Destroy widget (since gtk_widget_realize would otherwise crash)
+            Fallback to ImageSurface
+            */
+            #if OXYGEN_DEBUG
+            std::cerr
+                << "Oxygen::StyleHelper::initializeRefSurface - "
+                << " No valid screen found to create X11 surface."
+                << " Falling back to Cairo Image surface."
+                << std::endl;
+            #endif
+
+            gtk_widget_destroy( widget );
+            _refSurface.set( cairo_image_surface_create( CAIRO_FORMAT_ARGB32, 1, 1 ) );
+
+        }
+
     }
 
     //__________________________________________________________________
