@@ -26,7 +26,7 @@
 #include "oxygentileset.h"
 #include "oxygentilesetcache.h"
 
-#include <gdk/gdk.h>
+#include <gtk/gtk.h>
 
 namespace Oxygen
 {
@@ -43,16 +43,15 @@ namespace Oxygen
         public:
 
         //! constructor
-        StyleHelper( void ):
-            // for now we use a Cairo_image_surface for reference.
-            // will try using a cairo_x11_surface later
-            _refSurface( cairo_image_surface_create( CAIRO_FORMAT_ARGB32, 1, 1 ) )
-        {}
+        StyleHelper( void );
 
         //! destructor
         virtual ~StyleHelper( void )
         {}
 
+        //! initialize ref surface
+        void initializeRefSurface( void );
+
         //! separators
         void drawSeparator( Cairo::Context&, const ColorUtils::Rgba& color, int x, int y, int w, int h, bool vertical );
 
@@ -87,10 +86,6 @@ namespace Oxygen
             else return cairo_surface_create_similar( _refSurface, CAIRO_CONTENT_COLOR_ALPHA, w, h );
         }
 
-        //! access reference surface
-        const Cairo::Surface& refSurface( void ) const
-        { return _refSurface; }
-
         //!@name decoration specific helper functions
         //@{
         const Cairo::Surface& windecoButton(const ColorUtils::Rgba &color, bool pressed, int size = 21);
@@ -155,8 +150,14 @@ namespace Oxygen
         //! dots
         void renderDot( Cairo::Context&, const ColorUtils::Rgba&, int x, int y ) const;
 
+        //@}
+
         protected:
 
+        //! access reference surface
+        const Cairo::Surface& refSurface( void ) const
+        { return _refSurface; }
+
         // separator
         const Cairo::Surface& separator(const ColorUtils::Rgba &color, bool vertical, int size );
 
