@@ -21,9 +21,9 @@
 */
 
 #include "oxygenflags.h"
+#include "oxygencairosurface.h"
 
 #include <cairo.h>
-#include <gdk/gdk.h>
 #include <vector>
 
 namespace Oxygen
@@ -51,7 +51,7 @@ namespace Oxygen
         @param w2 width of the not-left-or-right chunks
         @param h2 height of the not-top-or-bottom chunks
         */
-        TileSet( GdkPixbuf*, int w1, int h1, int w2, int h2 );
+        TileSet( const Cairo::Surface& surface, int w1, int h1, int w2, int h2 );
 
         /*!
         Create a TileSet from a pixmap. The size of the top/left and bottom/right
@@ -69,11 +69,17 @@ namespace Oxygen
         @param w2 width of the not-left-or-right chunks
         @param h2 height of the not-top-or-bottom chunks
         */
-        TileSet( GdkPixbuf*, int w1, int h1, int w3, int h3, int x2, int y2, int w2, int h2 );
+        TileSet( const Cairo::Surface& surface, int w1, int h1, int w3, int h3, int x2, int y2, int w2, int h2 );
 
         //! destructor
         virtual ~TileSet();
 
+        //! copy constructor
+        TileSet( const TileSet& );
+
+        //! assignment operator
+        TileSet& operator = ( const TileSet& );
+
         /*!
         Flags specifying what sides to draw in ::render. Corners are drawn when
         the sides forming that corner are drawn, e.g. Top|Left draws the
@@ -109,7 +115,7 @@ namespace Oxygen
 
         //! is valid
         bool isValid( void ) const
-        { return width() > 0  && height() > 0 && _pixmaps.size() == 9; }
+        { return width() > 0  && height() > 0 && _surfaces.size() == 9; }
 
         /*!
         Fills the specified rect with tiled chunks. Corners are never tiled,
@@ -121,27 +127,25 @@ namespace Oxygen
 
         protected:
 
-        //! copy constructor
-        TileSet( const TileSet& );
-
-        //! assignment operator
-        TileSet& operator = ( const TileSet& );
-
-        private:
+        //!@name internal constructors
+        //@{
+        void init( const Cairo::Surface&, int w1, int h1, int w2, int h2 );
+        void init( const Cairo::Surface&, int w1, int h1, int w3, int h3, int x2, int y2, int w2, int h2 );
+        //@}
 
         //! shortcut to pixmap list
-        typedef std::vector< GdkPixbuf* > PixbufList;
+        typedef std::vector< Cairo::Surface > SurfaceList;
 
         //! initialize pixmap
-        void initPixmap( PixbufList&, GdkPixbuf*, int w, int h, int sx, int sy, int sw, int sh );
+        void initSurface( SurfaceList&, const Cairo::Surface&, int w, int h, int sx, int sy, int sw, int sh );
 
         //! copy pixmap
-        void copyPixmap( Cairo::Context&, int x, int y, GdkPixbuf*, int sx, int sy, int sw, int sh, cairo_extend_t ) const;
+        void copySurface( Cairo::Context&, int x, int y, const Cairo::Surface&, int sx, int sy, int sw, int sh, cairo_extend_t ) const;
 
         private:
 
         //! pixmap arry
-        PixbufList _pixmaps;
+        SurfaceList _surfaces;
 
         // dimensions
         int _w1;
