@@ -95,7 +95,7 @@ namespace Oxygen
 
         /*
         check event mask (for now we only need to do that for GtkWindow)
-        The idea is that if the window has been set to recieve button_press and button_release events
+        The idea is that if the window has been set to receive button_press and button_release events
         (which is not done by default), it likely means that it does something with such events,
         in which case we should not use them for grabbing
         */
@@ -383,13 +383,14 @@ namespace Oxygen
         if( GTK_IS_NOTEBOOK( widget ) )
         {
 
+            const GtkAllocation local( Gtk::gtk_widget_get_allocation( widget ) );
             Gtk::gtk_notebook_get_tabbar_rect( GTK_NOTEBOOK( widget ), &allocation );
-            allocation.x += wx - widget->allocation.x;
-            allocation.y += wy - widget->allocation.y;
+            allocation.x += wx - local.x;
+            allocation.y += wy - local.y;
 
         } else {
 
-            allocation = widget->allocation;
+            allocation = Gtk::gtk_widget_get_allocation( widget );
             allocation.x = wx;
             allocation.y = wy;
 
